Welcome to ClientVPS Mirrors

Help for package blsBandit
Title: Data Viewer for Bureau of Labor Statistics Data
Version: 0.1
Description: Allows users to easily visualize data from the BLS (United States of America Bureau of Labor Statistics) https://www.bls.gov. Currently unemployment data series U1-U6 are available. Not affiliated with the Bureau of Labor Statistics or United States Government.
License: MIT + file LICENSE
Imports: DBI (≥ 1.1.3), jsonlite (≥ 1.8.4), plotly (≥ 4.10.2), RSQLite (≥ 2.2.16), shiny (≥ 1.7.1), zoo (≥ 1.8-12)
Encoding: UTF-8
RoxygenNote: 7.2.0
NeedsCompilation: no
Packaged: 2023-08-22 21:58:33 UTC; Taco
Author: Jeremy Fitzpatrick [aut, cre]
Maintainer: Jeremy Fitzpatrick <jmfitzpa@gmail.com>
Repository: CRAN
Date/Publication: 2023-08-23 19:30:02 UTC

Run the BLS Viewer

Description

This function runs the BLS (US Bureau of Labor Statistics) data viewer. Currently this viewer allows the user to select and view unemployment data. The data is static as the package blsAPI is no longer available on CRAN. To install the latest version of blsBandit and the blsAPI with update data functionality install them from github. blsAPI<https://github.com/mikeasilva/blsAPI> blsBandit<https://github.com/Jeremy-Fitzpatrick/blsBandit> The blsBandit package is not affiliated with the Bureau of Labor Statistics or US Government.

Usage

blsViewer()

Value

No return value. The user can save charts from within the interface.

Examples

# Run the BLS data viewer.
if(interactive()){blsViewer()}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.